const { URLS } = require('../lib/init/constants');

module.exports = Object.assign(init, {
  options: ['--add', '--java:mvn', '--java:package'],
  shortcuts: [],
  flags: ['--force', '--verbose'],
  help: `
# SYNOPSIS

    *cds init* [<project>] [<options>]

    Initializes a new project in folder ./<project>, with the current
    working directory as default.

# OPTIONS

    *--add* <feature | comma-separated list of features>

        Add one or more features while creating the project.
        <feature> can be one of the following:

        *java*     - prepares as a Java-based project
        *hana*     - adds configuration for SAP HANA deployment.
        *mta*      - adds an _mta.yaml_ file out of CDS models and config.
        *pipeline* - adds files for CI/CD pipeline integration.

    *--java:mvn* <Comma separated maven archetype specific parameters>

        Add the given paramters to the archetype call.
        See _${URLS.MAVEN_ARCHETYPE_HELP}_
        for parameters supported by the archetype.

    *--force*

        Overwrite all files.

# EXAMPLES

    *cds init* test
    *cds init* test --add java
    *cds init* test --add java,hana
    *cds init* --add mta
    *cds init* --add java --java:mvn groupId=myGroup,artifactId=newId,package=my.company

# SEE ALSO

    *cds add* as shortcut for _cds init --add_.

`});

async function init(args, options = {}) {
  const CDSGenerator = require('../lib/init');
  const generator = new CDSGenerator();
  await generator.initCmd(args[0], options);
}
